@@ -63,11 +63,15 @@ class CoreSection(StaticSection):
     This should not be set for networks that do not support IRCv3 account
     capabilities."""
 
+    alias_nicks = ListAttribute('alias_nicks')
+    """List of alternate names recognized as the bot's nick for $nick and
+    $nickname regex substitutions"""
+
     auth_method = ChoiceAttribute('auth_method', choices=[
-        'nickserv', 'authserv', 'Q', 'sasl', 'server'])
+        'nickserv', 'authserv', 'Q', 'sasl', 'server', 'userserv'])
     """The method to use to authenticate with the server.
 
-    Can be ``nickserv``, ``authserv``, ``Q``, ``sasl``, or ``server``."""
+    Can be ``nickserv``, ``authserv``, ``Q``, ``sasl``, or ``server`` or ``userserv``."""
 
     auth_password = ValidatedAttribute('auth_password')
     """The password to use to authenticate with the server."""
@@ -99,7 +103,7 @@ class CoreSection(StaticSection):
                                              default='%Y-%m-%d - %T%Z')
     """The default format to use for time in messages."""
 
-    default_timezone = ValidatedAttribute('default_timezone')
+    default_timezone = ValidatedAttribute('default_timezone', default='UTC')
     """The default timezone to use for time in messages."""
 
     enable = ListAttribute('enable')
@@ -131,7 +135,7 @@ class CoreSection(StaticSection):
 
     Regular expression syntax is used"""
 
-    log_raw = ValidatedAttribute('log_raw', bool, default=True)
+    log_raw = ValidatedAttribute('log_raw', bool, default=False)
     """Whether a log of raw lines as sent and received should be kept."""
 
     logdir = FilenameAttribute('logdir', directory=True, default='logs')
@@ -186,10 +190,10 @@ class CoreSection(StaticSection):
     port = ValidatedAttribute('port', int, default=6667)
     """The port to connect on."""
 
-    prefix = ValidatedAttribute('prefix', default='\.')
+    prefix = ValidatedAttribute('prefix', default='\\.')
     """The prefix to add to the beginning of commands.
 
-    It is a regular expression (so the default, ``\.``, means commands start
+    It is a regular expression (so the default, ``\\.``, means commands start
     with a period), though using capturing groups will create problems."""
 
     reply_errors = ValidatedAttribute('reply_errors', bool, default=True)
